==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/OpenSCAD/Resources/translations/OpenSCAD.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
        <location filename="openscadprefs-base.ui" line="14"/>
        <source>General settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="26"/>
        <source>General OpenSCAD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="34"/>
        <source>OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="47"/>
        <source>The path to the OpenSCAD executeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="65"/>
        <source>OpenSCAD import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="73"/>
        <source>If this is checked, Features will claim thier children in the tree view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="76"/>
        <source>Use ViewProvider in Tree View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="93"/>
        <source>If this is checked, Multmatrix Object will be Parametric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="96"/>
        <source>Use Multmatrix Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="136"/>
        <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="116"/>
        <source>Maximum number of faces for polygons (fn)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="160"/>
        <source>OpenSCAD export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="168"/>
        <source>maximum fragment size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="198"/>
        <source>minimum angle for a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="191"/>
        <source>angular (fa)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="openscadprefs-base.ui" line="201"/>
        <source>°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="255"/>
        <source>minimum size of a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="233"/>
        <source>size (fs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="261"/>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="287"/>
        <source>convexity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="324"/>
        <source>Mesh fallback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="344"/>
        <source>Maxium Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="347"/>
        <source>MaxLength</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="354"/>
        <source>Maximum Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="386"/>
        <source>Maximum Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="379"/>
        <source>maxArea</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="430"/>
        <source>Local Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="433"/>
        <source>localLen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="462"/>
        <source>Deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="465"/>
        <source>deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="472"/>
        <source>Triangulation settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD</name>
    <message>
        <location filename="OpenSCADCommands.py" line="47"/>
        <source>Convert Edges to Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="101"/>
        <source>Please select 3 objects first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="334"/>
        <source>Unsupported Function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="334"/>
        <source>Press OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="946"/>
        <source>Projection Not yet Coded waiting for Peter Li</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="946"/>
        <source> Press OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="199"/>
        <source>Running OpenSCAD failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="162"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="163"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="164"/>
        <source>as Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="165"/>
        <source>Add OpenSCAD Element</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
        <location filename="OpenSCADCommands.py" line="207"/>
        <source>Add OpenSCAD Element...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="209"/>
        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
        <location filename="OpenSCADCommands.py" line="24"/>
        <source>Color Shapes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="26"/>
        <source>Color Shapes by validity and type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
        <location filename="OpenSCADCommands.py" line="45"/>
        <source>Convert Edges To Faces</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
        <location filename="OpenSCADCommands.py" line="86"/>
        <source>Expand Placements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="88"/>
        <source>Expand all placements downwards the FeatureTree</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="67"/>
        <source>Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="69"/>
        <source>Create Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
        <location filename="OpenSCADCommands.py" line="137"/>
        <source>Remove Objects and their Children</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="139"/>
        <source>Removes the selected objects and all children that are not referenced from other objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
        <location filename="OpenSCADCommands.py" line="105"/>
        <source>Replace Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="107"/>
        <source>Replace an object in the Feature Tree. Please select old, new and parent object</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/OpenSCAD/Resources/translations/OpenSCAD.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
        <location filename="openscadprefs-base.ui" line="14"/>
        <source>General settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="26"/>
        <source>General OpenSCAD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="34"/>
        <source>OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="47"/>
        <source>The path to the OpenSCAD executeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="65"/>
        <source>OpenSCAD import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="73"/>
        <source>If this is checked, Features will claim thier children in the tree view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="76"/>
        <source>Use ViewProvider in Tree View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="93"/>
        <source>If this is checked, Multmatrix Object will be Parametric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="96"/>
        <source>Use Multmatrix Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="136"/>
        <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="116"/>
        <source>Maximum number of faces for polygons (fn)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="160"/>
        <source>OpenSCAD export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="168"/>
        <source>maximum fragment size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="198"/>
        <source>minimum angle for a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="191"/>
        <source>angular (fa)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="openscadprefs-base.ui" line="201"/>
        <source>°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="255"/>
        <source>minimum size of a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="233"/>
        <source>size (fs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="261"/>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="287"/>
        <source>convexity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="324"/>
        <source>Mesh fallback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="344"/>
        <source>Maxium Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="347"/>
        <source>MaxLength</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="354"/>
        <source>Maximum Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="386"/>
        <source>Maximum Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="379"/>
        <source>maxArea</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="430"/>
        <source>Local Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="433"/>
        <source>localLen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="462"/>
        <source>Deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="465"/>
        <source>deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="472"/>
        <source>Triangulation settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD</name>
    <message>
        <location filename="OpenSCADCommands.py" line="120"/>
        <source>Convert Edges to Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="199"/>
        <source>Please select 3 objects first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="408"/>
        <source>Unsupported Function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="408"/>
        <source>Press OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="1091"/>
        <source>Projection Not yet Coded waiting for Peter Li</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="1091"/>
        <source> Press OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="243"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="244"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="245"/>
        <source>as Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="246"/>
        <source>Add OpenSCAD Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="319"/>
        <source>Perform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="320"/>
        <source>Mesh Boolean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADUtils.py" line="535"/>
        <source>Error all shapes must be either 2D or both must be 3D</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
        <location filename="OpenSCADCommands.py" line="361"/>
        <source>Add OpenSCAD Element...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="363"/>
        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
        <location filename="OpenSCADCommands.py" line="97"/>
        <source>Color Shapes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="99"/>
        <source>Color Shapes by validity and type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
        <location filename="OpenSCADCommands.py" line="118"/>
        <source>Convert Edges To Faces</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
        <location filename="OpenSCADCommands.py" line="179"/>
        <source>Expand Placements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="181"/>
        <source>Expand all placements downwards the FeatureTree</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
        <location filename="OpenSCADCommands.py" line="79"/>
        <source>Explode Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="81"/>
        <source>remove fusion, apply placement to children and color randomly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Hull</name>
    <message>
        <location filename="OpenSCADCommands.py" line="396"/>
        <source>Hull</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="398"/>
        <source>Perform Hull</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="160"/>
        <source>Increase Tolerance Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="162"/>
        <source>Create Feature that allows to increase the tolerance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
        <location filename="OpenSCADCommands.py" line="375"/>
        <source>Mesh Boolean...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="377"/>
        <source>Export objects as meshes and use OpenSCAD to perform a boolean operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Minkowski</name>
    <message>
        <location filename="OpenSCADCommands.py" line="417"/>
        <source>Minkowski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="419"/>
        <source>Perform Minkowski</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="139"/>
        <source>Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="141"/>
        <source>Create Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
        <location filename="OpenSCADCommands.py" line="218"/>
        <source>Remove Objects and their Children</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="220"/>
        <source>Removes the selected objects and all children that are not referenced from other objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
        <location filename="OpenSCADCommands.py" line="203"/>
        <source>Replace Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="205"/>
        <source>Replace an object in the Feature Tree. Please select old, new and parent object</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
